@@ -27,6 +27,9 @@
 #include "../base_db.h"
 #include "../utility_widgets/imageglom.h"
 
+namespace Glom
+{
+
 class Dialog_ImageObject
  : public Gtk::Dialog,
    public Base_DB //Give this class access to the current document, and to some utility methods.
@@ -50,4 +53,6 @@ protected:
   Glib::ustring m_table_name;
 };
 
+} //namespace Glom
+
 #endif //DIALOG_IMAGEOBJECT_H
