@@ -62,6 +62,9 @@ public:
   bool get_text_format_multiline() const;
   void set_text_format_multiline(bool value = true);
 
+  guint get_text_format_multiline_height_lines() const;
+  void set_text_format_multiline_height_lines(guint value);
+
   void change_field_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new);
 
   NumericFormat m_numeric_format; //Only used for numeric fields.
@@ -73,6 +76,8 @@ protected:
   bool m_choices_custom, m_choices_related;
 
   bool m_text_format_multiline;
+  guint m_text_multiline_height_lines; //The height in number of lines of text.
+  //Glib::ustring m_text_multiline_width_example; //An example string from which to calculate the width.
 
   Glib::ustring m_choices_related_field, m_choices_related_field_second;
 };
