@@ -37,11 +37,11 @@ Box_Data_List::Box_Data_List()
 {
   m_layout_name = "list";
 
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_data_layout_list"); //TODO: Use a generic layout dialog?
+  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_data_layout"); //TODO: Use a generic layout dialog?
   if(refXml)
   {
     Dialog_Layout_List* dialog = 0;
-    refXml->get_widget_derived("window_data_layout_list", dialog);
+    refXml->get_widget_derived("window_data_layout", dialog);
     if(dialog)
     {
       m_pDialogLayout = dialog;
@@ -113,6 +113,11 @@ bool Box_Data_List::fill_from_database()
 {
   bool result = false;
 
+  //Don't try to open a connection if there is no document,
+  //for instance, during application destruction.
+  if(!get_document())
+    return false;
+
   Bakery::BusyCursor busy_cursor(get_app_window());
 
   try
@@ -633,6 +638,19 @@ void Box_Data_List::create_layout_add_group(const sharedptr<LayoutGroup>& layout
         child_item->set_editable(false);
 
       //std::cout << "debug: adding column: " << child_item->get_name() << std::endl;
+
+      sharedptr<LayoutItem_Field> child_field = sharedptr<LayoutItem_Field>::cast_dynamic(child_item);
+      if(child_field)
+      {
+        //Check that the field really exists, to avoid SQL errors.
+        //This could probably only happen if we have failed to rename something everywhere, when the user has renamed something.
+        if(!get_field_exists_in_database(child_field->get_table_used(m_table_name), child_field->get_name()))
+        {
+          std::cerr << "debug: Box_Data_List::create_layout_add_group(): Field does not exist in database: table_name=" << child_field->get_table_used(m_table_name) << ", field_name=" << child_field->get_name() << std::endl;
+          continue;
+        }
+      }
+
       m_AddDel.add_column(child_item);
     }
   }
